﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data;

namespace Grid_ExcelEport
{
    public class UltraWinGridSample1 : DataSet
    {
        //Default contructor. Will default to buyer count 50 and order count 0.
        public UltraWinGridSample1()
        {
            this.ConfigureThis(50, 0);
        }

        //Contsructor, sets buyer count, assumes order count is 0.
        public UltraWinGridSample1(uint buyerCount)
        {
            this.ConfigureThis(buyerCount, 0);
        }

        //Constructor, sets buyer and order count.
        public UltraWinGridSample1(uint buyerCount, uint orderCount)
        {
            this.ConfigureThis(buyerCount, orderCount);
        }

        //Configures the dataset.
        private void ConfigureThis(uint buyerCount, uint orderCount)
        {
            bool orders;
            if (orderCount > 0) orders = true;
            else orders = false;

            this.CreateSampleSchema(orders);
            this.CreateSampleData(buyerCount, orderCount);
        }

        //Creates the schema for the sample data.
        private void CreateSampleSchema(bool orders)
        {
            DataColumn[] keys = new DataColumn[1];

            this.Tables.Add("Buyers");
            this.Tables[0].Columns.Add("AccountNumber", typeof(int));
            this.Tables[0].Columns.Add("FirstName", typeof(string));
            this.Tables[0].Columns.Add("LastName", typeof(string));
            this.Tables[0].Columns.Add("JoinDate", typeof(DateTime));
            this.Tables[0].Columns.Add("Zip", typeof(string));
            keys[0] = this.Tables[0].Columns["AccountNumber"];
            this.Tables[0].PrimaryKey = keys;
            this.Tables[0].Columns["AccountNumber"].AutoIncrementSeed = 1024;
            this.Tables[0].Columns["AccountNumber"].AutoIncrementStep = 1;
            this.Tables[0].Columns["AccountNumber"].AutoIncrement = true;

            if (orders)
            {
                this.Tables.Add("Orders");
                this.Tables[1].Columns.Add("AccountNumber", typeof(int));
                this.Tables[1].Columns.Add("OrderNumber", typeof(int));
                this.Tables[1].Columns.Add("OrderDate", typeof(DateTime));
                this.Tables[1].Columns.Add("Quantity", typeof(int));
                keys[0] = this.Tables[1].Columns["OrderNumber"];
                this.Tables[1].PrimaryKey = keys;
                this.Tables[1].Columns["OrderNumber"].AutoIncrementSeed = 556;
                this.Tables[1].Columns["OrderNumber"].AutoIncrementStep = 1;
                this.Tables[1].Columns["OrderNumber"].AutoIncrement = true;

                this.Relations.Add("BuyerToOrder", this.Tables[0].Columns[0],
                    this.Tables[1].Columns[0], true);
            }

        }

        //Populates the sample data.
        private void CreateSampleData(uint buyerCount, uint orderCount)
        {
            Random rndm = new Random();
            System.Collections.ArrayList accounts = new System.Collections.ArrayList();

            for (int i = 0; i < buyerCount; i++)
            {
                int y = rndm.Next(DateTime.Now.AddYears(-20).Year, DateTime.Now.Year);
                int m = rndm.Next(1, 13);
                int d = rndm.Next(1, DateTime.DaysInMonth(y, m));
                int zip = rndm.Next(1, 99999);
                string zipCode = zip.ToString();
                if (zipCode.Length < 5)
                {
                    do
                    {
                        zipCode = 0 + zipCode;
                    }
                    while (zipCode.Length < 5);
                }

                DateTime joinDate = new DateTime(y, m, d);

                string fn = firstNames[rndm.Next(0, firstNames.Length)];
                string ln = lastNames[rndm.Next(0, lastNames.Length)];

                this.Tables["Buyers"].Rows.Add(
                    new object[] { null, fn, ln, joinDate, zipCode });

                object[] row = this.Tables["Buyers"].Rows[i].ItemArray;
                accounts.Add(Convert.ToInt32(row[0]));
            }

            if (orderCount > 0)
            {
                for (int i = 0; i < orderCount; i++)
                {
                    //Get a random account number that was added to the Buyers table.
                    int accountNumber = Convert.ToInt32(accounts[rndm.Next(0, accounts.Count)]);

                    //Get the joinDate corresponding to the Buyers account number.                    
                    object[] row = (this.Tables[0].Rows.Find(accountNumber)).ItemArray;
                    DateTime joinDate = (DateTime)row.GetValue(3);

                    //Set an order date.
                    DateTime orderDate = new DateTime();
                    do
                    {
                        int y = rndm.Next(DateTime.Now.AddYears(-20).Year, DateTime.Now.Year);
                        int m = rndm.Next(1, 13);
                        int d = rndm.Next(1, DateTime.DaysInMonth(y, m));
                        orderDate = new DateTime(y, m, d);
                    }
                    while (orderDate < joinDate);

                    //Add the row.
                    this.Tables["Orders"].Rows.Add(new object[] { accountNumber, null, orderDate, rndm.Next(1, 100) });
                }
            }
        }

        //Name arrays.
        private string[] firstNames = { "Mary", "Scott", "John", "Jim", "Keith", "Brian",
        "Harry", "Richard", "Robert", "Michael", "Matt", "George", "Don", "Vince",
        "Joe", "Jon", "Yale", "Nick", "Neil", "Bart", "William", "Bill", "Fry",
        "Jason", "Stephanie", "Bree", "Kim", "Kelly", "Lisa", "Joan", "Jennifer" };
        private string[] lastNames = { "Evans", "Harrison", "Smith", "Doe", "Johnson",
        "Griggs", "Harrelson", "Statham", "Williams", "Williamson", "Wells",
        "Cafaro", "Orris", "Dunn", "Taylor", "Lawrence", "Jennings", "Morris",
        "Lincoln", "Ford"};

        //Static helper method to set some basic layout settings.
        public static void SetGridLayout(Infragistics.Win.UltraWinGrid.UltraGrid ug)
        {
            //Scroll settings.
            ug.DisplayLayout.ScrollStyle = Infragistics.Win.UltraWinGrid.ScrollStyle.Immediate;
            ug.DisplayLayout.ScrollBounds = Infragistics.Win.UltraWinGrid.ScrollBounds.ScrollToFill;

            //Caption changes
            ug.DisplayLayout.Bands[0].Columns["AccountNumber"].Header.Caption = "Account No.";
            ug.DisplayLayout.Bands[0].Columns["FirstName"].Header.Caption = "First Name";
            ug.DisplayLayout.Bands[0].Columns["LastName"].Header.Caption = "Last Name";
            ug.DisplayLayout.Bands[0].Columns["JoinDate"].Header.Caption = "Joined";
            ug.DisplayLayout.Bands[0].Columns["Zip"].Header.Caption = "Zip Code";

            if (ug.DisplayLayout.Bands.Count > 1)
            {
                //Expansion indicators.
                ug.DisplayLayout.Override.ExpansionIndicator = Infragistics.Win.UltraWinGrid.ShowExpansionIndicator.CheckOnDisplay;

                //Hide AccountNumber column.
                ug.DisplayLayout.Bands[1].Columns["AccountNumber"].Hidden = true;

                //Caption changes.
                ug.DisplayLayout.Bands[1].Columns["OrderNumber"].Header.Caption = "Order No.";
                ug.DisplayLayout.Bands[1].Columns["OrderDate"].Header.Caption = "Order Date";
            }
        }
    }
}
